unit PhryTrackBar;

interface

uses
  Windows, Classes, Graphics, Controls, SysUtils;

type
  TTrackOrientation = (trHorizontal, trVertical);
  TPhryTrackBar = class(TGraphicControl)
  private
    { Private declarations }
    Active :Boolean;
    InLoad :Boolean;
    FMin :integer;
    FMax :integer;
    FFileName :string;
    FTrackBarWidth :integer;
    FTrackBarHeight :integer;
    FReverse :boolean;
    FOnSliderPress :TNotifyEvent;
    FOnSliderRelease :TNotifyEvent;
    FOnSliderMove :TNotifyEvent;
    FOrientation :TTrackOrientation;
    Pushed :integer;
    SliderWidth :integer;
    SliderHeight :integer;
    StateCount :integer;
    CurrentState :integer;
    FPosition :integer;
    SliderPos :integer;
    picSource :TPicture;
    bmpMed    :TBitmap;
    bmpCanvas :TBitmap;
    offset :integer;
    procedure SetFileName(name :string);
    procedure SetBarWidth(Value :integer);
    procedure SetBarHeight(Value :integer);
    procedure SetPosition(Value :integer);
    procedure HandleMouseDown(Sender: TObject; Button: TMouseButton;
                              Shift: TShiftState; X, Y: Integer);
    procedure HandleMouseMove(Sender: TObject; Shift: TShiftState;
                              X, Y: Integer);
    procedure HandleMouseUp(Sender: TObject; Button: TMouseButton;
                            Shift: TShiftState; X, Y: Integer);
    procedure SetMin(Value :integer);
    procedure SetMax(Value :integer);
    procedure SetOrientation(Value :TTrackOrientation);
    procedure SetReverse(Value :boolean);
  protected
    { Protected declarations }
    procedure Paint; override;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
  published
    { Published declarations }
    property Reverse :boolean read FReverse write SetReverse;
    property Orientation :TTrackOrientation read FOrientation write SetOrientation;
    property Min :integer read FMin write SetMin;
    property Max :integer read FMax write SetMax;
    property TrackBarWidth :integer read FTrackBarWidth write SetBarWidth;
    property TrackBarHeight :integer read FTrackBarHeight write SetBarHeight;
    property OnSliderPress :TNotifyEvent read FOnSliderPress write FOnSliderPress;
    property OnSliderRelease :TNotifyEvent read FOnSliderRelease write FOnSliderRelease;
    property OnSliderMove :TNotifyEvent read FOnSliderMove write FOnSliderMove;
    property FileName :string read FFileName write SetFileName;
    property Position :integer read FPosition write SetPosition;
  end;

procedure Register;

implementation

const
bufDefHorizontal :Array[1..9414] of byte = (
66,77,198,36,0,0,0,0,0,0,54,0,0,0,40,0,
0,0,156,0,0,0,20,0,0,0,1,0,24,0,0,0,
0,0,144,36,0,0,196,14,0,0,196,14,0,0,0,0,
0,0,0,0,0,0,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,255,255,255,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
0,0,0,255,255,255,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,0,0,0,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,255,255,255,223,
223,223,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,128,128,128,0,0,0,255,255,255,223,223,223,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,128,128,128,0,
0,0,192,192,192,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,192,192,192,
255,255,255,223,223,223,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,128,128,128,0,0,0,255,255,255,223,223,
223,192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,
128,128,128,0,0,0,192,192,192,128,128,128,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,255,255,
255,192,192,192,255,255,255,223,223,223,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,
255,255,223,223,223,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,128,128,128,0,0,0,192,192,192,128,128,128,
0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,
223,223,255,255,255,192,192,192,255,255,255,223,223,223,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,
0,0,0,255,255,255,223,223,223,192,192,192,255,255,255,192,
192,192,255,255,255,192,192,192,128,128,128,0,0,0,192,192,
192,128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,223,223,223,255,255,255,192,192,192,255,255,255,223,
223,223,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,128,128,128,0,0,0,255,255,255,223,223,223,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,128,128,128,0,
0,0,192,192,192,128,128,128,0,0,0,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,223,223,223,255,255,255,192,192,192,
255,255,255,223,223,223,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,128,128,128,0,0,0,255,255,255,223,223,
223,192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,
128,128,128,0,0,0,192,192,192,128,128,128,0,0,0,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,223,223,223,255,255,
255,192,192,192,255,255,255,223,223,223,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,
255,255,223,223,223,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,128,128,128,0,0,0,192,192,192,128,128,128,
0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,
223,223,255,255,255,192,192,192,255,255,255,223,223,223,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,
0,0,0,255,255,255,223,223,223,192,192,192,255,255,255,192,
192,192,255,255,255,192,192,192,128,128,128,0,0,0,192,192,
192,128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,223,223,223,255,255,255,192,192,192,255,255,255,223,
223,223,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,128,128,128,0,0,0,255,255,255,223,223,223,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,128,128,128,0,
0,0,192,192,192,128,128,128,0,0,0,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,223,223,223,255,255,255,192,192,192,
255,255,255,223,223,223,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,128,128,128,0,0,0,255,255,255,223,223,
223,192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,
128,128,128,0,0,0,192,192,192,128,128,128,0,0,0,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,223,223,223,255,255,
255,192,192,192,255,255,255,223,223,223,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,
255,255,223,223,223,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,128,128,128,0,0,0,192,192,192,128,128,128,
0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,223,
223,223,255,255,255,192,192,192,255,255,255,223,223,223,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,
0,0,0,255,255,255,223,223,223,192,192,192,255,255,255,192,
192,192,255,255,255,192,192,192,128,128,128,0,0,0,192,192,
192,128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,223,223,223,255,255,255,192,192,192,255,255,255,223,
223,223,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,128,128,128,0,0,0,255,255,255,223,223,223,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,128,128,128,0,
0,0,192,192,192,128,128,128,0,0,0,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,223,223,223,255,255,255,192,192,192,
255,255,255,223,223,223,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,128,128,128,0,0,0,255,255,255,223,223,
223,192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,
128,128,128,0,0,0,192,192,192,128,128,128,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,223,223,223,255,255,
255,192,192,192,255,255,255,223,223,223,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,
255,255,223,223,223,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,128,128,128,0,0,0,192,192,192,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,255,255,255,192,192,192,255,255,255,223,223,223,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,
0,0,0,255,255,255,223,223,223,192,192,192,255,255,255,192,
192,192,255,255,255,192,192,192,128,128,128,0,0,0,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,255,255,255,223,
223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,223,
223,128,128,128,0,0,0,255,255,255,223,223,223,223,223,223,
223,223,223,223,223,223,223,223,223,223,223,223,128,128,128,0,
0,0,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,0,0,0,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,0,0,0);
bufDefVertical :Array[1..9414] of byte = (
66,77,198,36,0,0,0,0,0,0,54,0,0,0,40,0,
0,0,20,0,0,0,156,0,0,0,1,0,24,0,0,0,
0,0,144,36,0,0,196,14,0,0,196,14,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,255,255,255,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,0,0,0,255,255,
255,192,192,192,192,192,192,255,255,255,192,192,192,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,255,
255,255,192,192,192,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,128,128,128,0,0,0,255,255,255,192,192,192,
255,255,255,192,192,192,255,255,255,192,192,192,255,255,255,192,
192,192,255,255,255,192,192,192,255,255,255,192,192,192,255,255,
255,192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,
128,128,128,0,0,0,255,255,255,192,192,192,192,192,192,255,
255,255,192,192,192,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,192,192,192,255,255,255,192,192,192,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,128,128,128,0,
0,0,255,255,255,192,192,192,255,255,255,192,192,192,255,255,
255,192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,
255,255,255,192,192,192,255,255,255,192,192,192,255,255,255,192,
192,192,255,255,255,192,192,192,128,128,128,0,0,0,255,255,
255,192,192,192,192,192,192,255,255,255,192,192,192,255,255,255,
192,192,192,255,255,255,192,192,192,255,255,255,192,192,192,255,
255,255,192,192,192,255,255,255,192,192,192,255,255,255,192,192,
192,255,255,255,128,128,128,0,0,0,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,
255,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,0,0,0,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,0,0,0,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,0,0,0,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,192,192,192,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
128,128,128,0,0,0,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,192,192,192,255,255,255,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,128,128,128,0,
0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,
255,255,255,192,192,192,255,255,255,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,128,128,128,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,
192,192,255,255,255,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,
128,128,128,128,128,128,128,128,128,128,128,128,128,128,255,255,
255,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,192,
192,192,192,192,192,192);

procedure TPhryTrackBar.SetReverse(Value :boolean);

begin
  FReverse := Value;
  SetPosition(FPosition);
  Repaint;
end;

procedure TPhryTrackBar.SetOrientation(Value :TTrackOrientation);

var
  i :integer;

begin
  if ((FOrientation = trHorizontal) and (Value = trVertical)) or
     ((FOrientation = trVertical) and (Value = trHorizontal)) then
  begin
    if not (csLoading in ComponentState) then
    begin
      i := FTrackBarWidth;
      FTrackBarWidth := FTrackBarHeight;
      FTrackBarHeight := i;
      i := Width;
      Width := Height;
      Height := i;
    end;
    FOrientation := Value;
    SetFileName(FFileName);
  end else
    FOrientation := Value;
  Repaint;
end;

procedure TPhryTrackBar.SetMin(Value :integer);

begin
  if Value >= FMax then
    Value := FMax-1;
  FMin := Value;
  SetPosition(FPosition);
  Repaint;
end;

procedure TPhryTrackBar.SetMax(Value :integer);

begin
  if Value <= FMin then
    Value := FMin+1;
  FMax := Value;
  SetPosition(FPosition);
  Repaint;
end;

procedure TPhryTrackBar.SetBarWidth(Value :integer);

begin
  FTrackBarWidth := Value;
  if Active then
    SetFileName(FFileName);
end;

procedure TPhryTrackBar.SetBarHeight(Value :integer);

begin
  FTrackBarHeight := Value;
  if Active then
    SetFileName(FFileName);
end;

procedure TPhryTrackBar.SetPosition(Value :integer);

begin
  if Value > FMax then
    Value := FMax;
  if Value < FMin then
    Value := FMin;
  FPosition := Value;
  CurrentState := Round((FPosition - FMin) * (StateCount-1) / (FMax - FMin));
  if FReverse then
    CurrentState := StateCount - CurrentState - 1;
  if Orientation = trHorizontal then
    SliderPos := Round((FPosition - FMin) * (Width - SliderWidth) / (FMax - FMin))
  else
    SliderPos := Round((FPosition - FMin) * (Height - SliderHeight) / (FMax - FMin));
  Repaint;
end;

procedure TPhryTrackBar.SetFileName(Name :string);

var
  s :TMemoryStream;

begin
  Active := False;
  InLoad := True;
  FFileName := Name;
  if FileExists(Name) then
    picSource.LoadFromFile(Name)
  else
  begin
    s := TMemoryStream.Create;
    if Orientation = trHorizontal then
    begin
      FTrackBarWidth := 138;
      FTrackBarHeight := 20;
      s.SetSize(Sizeof(bufDefHorizontal));
      s.Seek(0, soFromBeginning);
      s.Write(bufDefHorizontal, Sizeof(bufDefHorizontal));
      s.Seek(0, soFromBeginning);
    end else
    begin
      FTrackBarWidth := 20;
      FTrackBarHeight := 138;
      s.SetSize(Sizeof(bufDefVertical));
      s.Seek(0, soFromBeginning);
      s.Write(bufDefVertical, Sizeof(bufDefVertical));
      s.Seek(0, soFromBeginning);
    end;
    picSource.Bitmap.LoadFromStream(s);
    s.Destroy;
  end;
  if Orientation = trHorizontal then
  begin
    StateCount := picSource.Height div FTrackBarHeight;
    SliderWidth := (picSource.Width - FTrackBarWidth) div 2;
    SliderHeight := FTrackBarHeight;
  end else
  begin
    StateCount := picSource.Width div FTrackBarWidth;
    SliderHeight := (picSource.Height - FTrackBarHeight) div 2;
    SliderWidth := FTrackBarWidth;
  end;
  if FileExists(Name) then
    Active := True;
  InLoad := False;
  SetPosition(FPosition);
end;

procedure TPhryTrackBar.Paint;

var
  r1, r2 :TRect;

begin
  if not InLoad then
  begin
    if Orientation = trHorizontal then
    begin
      r1 := Rect(0, 0, FTrackBarWidth, FTrackBarHeight);
      r2 := Rect(0, FTrackBarHeight * CurrentState,
                 FTrackBarWidth, FTrackBarHeight * (CurrentState+1));
      bmpMed.Width := FTrackBarWidth;
      bmpMed.Height := FTrackBarHeight;
      bmpMed.Canvas.CopyRect(r1, picSource.Bitmap.Canvas, r2);
      bmpCanvas.Height := Height;
      bmpCanvas.Width := Width;
      bmpCanvas.Canvas.StretchDraw(ClientRect, bmpMed);
      r1 := Rect(FTrackBarWidth + Pushed, FTrackBarHeight * CurrentState,
                 FTrackBarWidth + SliderWidth + Pushed, FTrackBarHeight * (CurrentState+1));
      r2 := Rect(0, 0, SliderWidth, sliderHeight);
      bmpMed.Width := SliderWidth;
      bmpMed.Height := SliderHeight;
      bmpMed.Canvas.CopyRect(r2, picSource.Bitmap.Canvas, r1);
      r2 := Rect(SliderPos, 0, SliderPos + SliderWidth, Height);
      bmpCanvas.Canvas.StretchDraw(r2, bmpMed);
      Canvas.Draw(0, 0, bmpCanvas);
    end else
    begin
      r1 := Rect(0, 0, FTrackBarWidth, FTrackBarHeight);
      r2 := Rect(FTrackBarWidth * CurrentState, 0,
                 FTrackBarWidth * (CurrentState+1), FTrackBarHeight);
      bmpMed.Width := FTrackBarWidth;
      bmpMed.Height := FTrackBarHeight;
      bmpMed.Canvas.CopyRect(r1, picSource.Bitmap.Canvas, r2);
      bmpCanvas.Height := Height;
      bmpCanvas.Width := Width;
      bmpCanvas.Canvas.StretchDraw(ClientRect, bmpMed);
      r1 := Rect(FTrackBarWidth * CurrentState, FTrackBarHeight + Pushed,
                 FTrackBarWidth * (CurrentState+1), FTrackBarHeight + SliderHeight + Pushed);
      r2 := Rect(0, 0, SliderWidth, sliderHeight);
      bmpMed.Width := SliderWidth;
      bmpMed.Height := SliderHeight;
      bmpMed.Canvas.CopyRect(r2, picSource.Bitmap.Canvas, r1);
      r2 := Rect(0, SliderPos, Width, SliderPos + SliderHeight);
      bmpCanvas.Canvas.StretchDraw(r2, bmpMed);
      Canvas.Draw(0, 0, bmpCanvas);
    end;
  end;
end;

constructor TPhryTrackBar.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle + [csOpaque];
  Active := False;
  InLoad := True;
  FReverse := False;
  Pushed := 0;
  FMin := 0;
  FMax := 100;
  FOrientation := trHorizontal;
  FPosition := FMin;
  Width := 138;
  Height := 20;
  FTrackBarWidth := Width;
  FTrackBarHeight := Height;
  picSource := TPicture.Create;
  bmpCanvas := TBitmap.Create;
  bmpMed := TBitmap.Create;
  bmpCanvas.Width := Width;
  bmpCanvas.Height := Height;
//  OnResize := ResizeTrackBar;
  OnMouseDown := HandleMouseDown;
  OnMouseMove := HandleMouseMove;
  OnMouseUp := HandleMouseUp;
//  Visible := True;
  SetFileName('');
end;

procedure TPhryTrackBar.HandleMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  if Orientation = trHorizontal then
  begin
    if (X >= SliderPos) and (X < SliderPos + SliderWidth) then
    begin
      offset := X - SliderPos;
      Pushed := SliderWidth;
      Repaint;
      if Assigned(FOnSliderPress) then
        FOnSliderPress(Sender);
    end;
  end else
  begin
    if (Y >= SliderPos) and (Y < SliderPos + SliderHeight) then
    begin
      offset := Y - SliderPos;
      Pushed := SliderHeight;
      Repaint;
      if Assigned(FOnSliderPress) then
        FOnSliderPress(Sender);
    end;
  end;
end;

procedure TPhryTrackBar.HandleMouseMove(Sender: TObject; Shift: TShiftState; X,
  Y: Integer);

var
  NewPos :integer;

begin
  if Pushed <> 0 then
  begin
    if Orientation = trHorizontal then
    begin
      NewPos := X - Offset;
      if NewPos > Width - SliderWidth then
        NewPos := Width - SliderWidth;
      if NewPos < 0 then
        NewPos := 0;
      SliderPos := NewPos;
      SetPosition(Round(SliderPos * (FMax - FMin) / (Width - SliderWidth)) + FMin);
    end else
    begin
      NewPos := Y - Offset;
      if NewPos > Height - SliderHeight then
        NewPos := Height - SliderHeight;
      if NewPos < 0 then
        NewPos := 0;
      SliderPos := NewPos;
      SetPosition(Round(SliderPos * (FMax - FMin) / (Height - SliderHeight)) + FMin);
    end;
    if Assigned(FOnSliderMove) then
      FOnSliderMove(Sender);
  end;
end;

procedure TPhryTrackBar.HandleMouseUp(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  if Pushed <> 0 then
  begin
    Pushed := 0;
    Repaint;
    if Assigned(FOnSliderRelease) then
      FOnSliderRelease(Sender);
  end;
end;

procedure Register;
begin
  RegisterComponents('Phry', [TPhryTrackBar]);
end;
end.
